__author__ = "Microsoft Apex Lab"
__copyright__ = "Copyright 2017, Microsoft Corporation"
__credits__ = ["Eric Hanko", "Jacob Zaval", "Michael Brown", "Andre Shields", "Ryan Dominguez", "Eammon Hanlon"]
__license__ = "MIT"
__email__ = "apxlab@microsoft.com"

